@@ -1,7 +1,7 @@
 use crate::parser::parol_grammar_trait::ParolGrammarTrait;
-use anyhow::{anyhow, Result};
 use id_tree::Tree;
 use log::trace;
+use miette::{miette, Result};
 use parol_runtime::parser::{ParseTreeStackEntry, ParseTreeType};
 use std::fmt::{Debug, Display, Error, Formatter};
 
@@ -253,10 +253,10 @@ impl ParolGrammar {
                     trace!("{}", self.trace_item_stack(context));
                     Ok(())
                 } else {
-                    Err(anyhow!("{}: Unknown scanner name '{}'", context, s))
+                    Err(miette!("{}: Unknown scanner name '{}'", context, s))
                 }
             }
-            _ => Err(anyhow!(
+            _ => Err(miette!(
                 "{}: Expected [StateList, Factor::NonTerminal] on TOS, found [{:?}, {:?}]",
                 context,
                 l,
@@ -326,7 +326,7 @@ impl ParolGrammarTrait for ParolGrammar {
             self.start_symbol = s;
             Ok(())
         } else {
-            Err(anyhow!(
+            Err(miette!(
                 "{}: Expected 'Fac(Factor::NonTerminal)' on TOS.",
                 context
             ))
@@ -360,7 +360,7 @@ impl ParolGrammarTrait for ParolGrammar {
             self.title = Some(s);
             Ok(())
         } else {
-            Err(anyhow!(
+            Err(miette!(
                 "{}: Expected 'Fac(Factor::Terminal)' on TOS.",
                 context
             ))
@@ -382,7 +382,7 @@ impl ParolGrammarTrait for ParolGrammar {
             self.comment = Some(s);
             Ok(())
         } else {
-            Err(anyhow!(
+            Err(miette!(
                 "{}: Expected 'Fac(Factor::Terminal)' on TOS.",
                 context
             ))
@@ -404,7 +404,7 @@ impl ParolGrammarTrait for ParolGrammar {
             self.current_scanner.line_comments.push(s);
             Ok(())
         } else {
-            Err(anyhow!(
+            Err(miette!(
                 "{}: Expected 'Fac(Factor::Terminal)' on TOS.",
                 context
             ))
@@ -428,13 +428,13 @@ impl ParolGrammarTrait for ParolGrammar {
                 self.current_scanner.block_comments.push((s2, s1));
                 Ok(())
             } else {
-                Err(anyhow!(
+                Err(miette!(
                     "{}: Expected 'Fac(Factor::Terminal)' on TOS.",
                     context
                 ))
             }
         } else {
-            Err(anyhow!(
+            Err(miette!(
                 "{}: Expected 'Fac(Factor::Terminal)' on TOS.",
                 context
             ))
@@ -488,13 +488,13 @@ impl ParolGrammarTrait for ParolGrammar {
                 self.push(ParolGrammarItem::Prod(Production::new(lhs, rhs)), context);
                 Ok(())
             } else {
-                Err(anyhow!(
+                Err(miette!(
                     "{}: Expected 'Fac(Factor::NonTerminal)' on TOS.",
                     context
                 ))
             }
         } else {
-            Err(anyhow!("{}: Expected 'Alts' on TOS.", context))
+            Err(miette!("{}: Expected 'Alts' on TOS.", context))
         }
     }
 
@@ -516,10 +516,10 @@ impl ParolGrammarTrait for ParolGrammar {
                 self.push(ParolGrammarItem::Alts(alts), context);
                 Ok(())
             } else {
-                Err(anyhow!("{}: Expected 'Alt' on TOS.", context))
+                Err(miette!("{}: Expected 'Alt' on TOS.", context))
             }
         } else {
-            Err(anyhow!("{}: Expected 'Alts' on TOS.", context))
+            Err(miette!("{}: Expected 'Alts' on TOS.", context))
         }
     }
 
@@ -542,10 +542,10 @@ impl ParolGrammarTrait for ParolGrammar {
                 self.push(ParolGrammarItem::Alts(alts), context);
                 Ok(())
             } else {
-                Err(anyhow!("{}: Expected 'Alt' on TOS.", context))
+                Err(miette!("{}: Expected 'Alt' on TOS.", context))
             }
         } else {
-            Err(anyhow!("{}: Expected 'Alts' on TOS.", context))
+            Err(miette!("{}: Expected 'Alts' on TOS.", context))
         }
     }
 
@@ -577,10 +577,10 @@ impl ParolGrammarTrait for ParolGrammar {
                 self.push(ParolGrammarItem::Alt(alt), context);
                 Ok(())
             } else {
-                Err(anyhow!("{}: Expected 'Fac' on TOS.", context))
+                Err(miette!("{}: Expected 'Fac' on TOS.", context))
             }
         } else {
-            Err(anyhow!("{}: Expected 'Alt' on TOS.", context))
+            Err(miette!("{}: Expected 'Alt' on TOS.", context))
         }
     }
 
@@ -613,10 +613,10 @@ impl ParolGrammarTrait for ParolGrammar {
                 self.push(ParolGrammarItem::Fac(Factor::Terminal(s, sc)), context);
                 Ok(())
             } else {
-                Err(anyhow!("{}: Expected 'StateList' on TOS.", context))
+                Err(miette!("{}: Expected 'StateList' on TOS.", context))
             }
         } else {
-            Err(anyhow!("{}: Expected 'Factor::Terminal' on TOS.", context))
+            Err(miette!("{}: Expected 'Factor::Terminal' on TOS.", context))
         }
     }
 
@@ -644,10 +644,10 @@ impl ParolGrammarTrait for ParolGrammar {
                 self.push(ParolGrammarItem::Fac(Factor::Group(alts)), context);
                 Ok(())
             } else {
-                Err(anyhow!("{}: Expected 'Factor' on TOS.", context))
+                Err(miette!("{}: Expected 'Factor' on TOS.", context))
             }
         } else {
-            Err(anyhow!("{}: Expected 'Alts' on TOS.", context))
+            Err(miette!("{}: Expected 'Alts' on TOS.", context))
         }
     }
 
@@ -675,10 +675,10 @@ impl ParolGrammarTrait for ParolGrammar {
                 self.push(ParolGrammarItem::Fac(Factor::Optional(alts)), context);
                 Ok(())
             } else {
-                Err(anyhow!("{}: Expected 'Factor' on TOS.", context))
+                Err(miette!("{}: Expected 'Factor' on TOS.", context))
             }
         } else {
-            Err(anyhow!("{}: Expected 'Alts' on TOS.", context))
+            Err(miette!("{}: Expected 'Alts' on TOS.", context))
         }
     }
 
@@ -706,10 +706,10 @@ impl ParolGrammarTrait for ParolGrammar {
                 self.push(ParolGrammarItem::Fac(Factor::Repeat(alts)), context);
                 Ok(())
             } else {
-                Err(anyhow!("{}: Expected 'Factor' on TOS.", context))
+                Err(miette!("{}: Expected 'Factor' on TOS.", context))
             }
         } else {
-            Err(anyhow!("{}: Expected 'Alts' on TOS.", context))
+            Err(miette!("{}: Expected 'Alts' on TOS.", context))
         }
     }
 
@@ -731,7 +731,7 @@ impl ParolGrammarTrait for ParolGrammar {
             );
             Ok(())
         } else {
-            Err(anyhow!(
+            Err(miette!(
                 "{}: Token expected, found {}",
                 context,
                 parse_tree_item
@@ -756,7 +756,7 @@ impl ParolGrammarTrait for ParolGrammar {
             self.push(ParolGrammarItem::Fac(Factor::Terminal(s, vec![0])), context);
             Ok(())
         } else {
-            Err(anyhow!(
+            Err(miette!(
                 "{}: Token expected, found {}",
                 context,
                 parse_tree_item
@@ -788,7 +788,7 @@ impl ParolGrammarTrait for ParolGrammar {
             trace!("{}", self);
             Ok(())
         } else {
-            Err(anyhow!(
+            Err(miette!(
                 "{}: Expected 'Factor::NonTerminal' on TOS.",
                 context
             ))
@@ -863,10 +863,10 @@ impl ParolGrammarTrait for ParolGrammar {
                 trace!("{}", self.trace_item_stack(context));
                 Ok(())
             } else {
-                Err(anyhow!("{}: Unknown scanner name '{}'", context, s))
+                Err(miette!("{}: Unknown scanner name '{}'", context, s))
             }
         } else {
-            Err(anyhow!(
+            Err(miette!(
                 "{}: Expected 'Fac(Factor::NonTerminal)' on TOS.",
                 context
             ))
@@ -899,10 +899,10 @@ impl ParolGrammarTrait for ParolGrammar {
                 trace!("{}", self.trace_item_stack(context));
                 Ok(())
             } else {
-                Err(anyhow!("{}: Unknown scanner name '{}'", context, s))
+                Err(miette!("{}: Unknown scanner name '{}'", context, s))
             }
         } else {
-            Err(anyhow!(
+            Err(miette!(
                 "{}: Expected 'Fac(Factor::NonTerminal)' on TOS.",
                 context
             ))
